@@ -1543,7 +1543,7 @@ static void
 args_write_line_v (GString *f, gsize nargs, const char **args)
 {
 	gsize i;
-	gboolean printed;
+	gboolean printed = FALSE;
 
 	nm_assert (args);
 	nm_assert (args[0]);
@@ -1836,7 +1836,7 @@ do_export_create (NMConnection *connection, const char *path, GError **error)
 		proxy_username = nm_setting_vpn_get_data_item (s_vpn, NM_OPENVPN_KEY_HTTP_PROXY_USERNAME);
 		proxy_password = nm_setting_vpn_get_secret (s_vpn, NM_OPENVPN_KEY_HTTP_PROXY_PASSWORD);
 
-		if (nm_streq (proxy_type, "http") && proxy_server && proxy_port) {
+		if (nm_streq (proxy_type, "http") && proxy_server) {
 			char *authfile, *authcontents, *base, *dirname;
 
 			if (!proxy_port)
@@ -1866,7 +1866,7 @@ do_export_create (NMConnection *connection, const char *path, GError **error)
 				g_free (authcontents);
 			}
 			g_free (authfile);
-		} else if (nm_streq (proxy_type, "socks") && proxy_server && proxy_port) {
+		} else if (nm_streq (proxy_type, "socks") && proxy_server) {
 			if (!proxy_port)
 				proxy_port = "1080";
 			args_write_line (f, NMV_OVPN_TAG_SOCKS_PROXY, proxy_server, proxy_port);
